@@ -11,18 +11,21 @@ __docformat__ = "restructuredtext en"
 
 import os
 import os.path as osp
+import errno
 import shutil
 
 from logilab.mtconverter import need_guess, guess_mimetype_and_encoding
 
-from cubicweb import QueryError, ValidationError, Binary
+from cubicweb import QueryError, ValidationError
 from cubicweb.server import hook, session, Service
-from cubicweb.predicates import (is_instance, score_entity, configuration_values,
-                                match_user_groups)
+from cubicweb.predicates import is_instance, score_entity, match_user_groups
 
 from cubes.vcsfile import IMMUTABLE_ATTRIBUTES, bridge
 
 def repo_cache_dir(config):
+    """Return the directory to use for repo cache
+
+    This function create directory if necessary."""
     directory = config['local-repo-cache-root']
     if not osp.isabs(directory):
         directory = osp.join(config.appdatahome, directory)
@@ -32,8 +35,8 @@ def repo_cache_dir(config):
             os.makedirs(directory)
         except Exception:
             config.critical('could not find local repo cache directory; check '
-                            'local-repo-cache-root option whose present value is %r)',
-                            config['local-repo-cache-root'])
+                            'local-repo-cache-root option whose present value '
+                            'is %r)', config['local-repo-cache-root'])
             raise
     return directory
 
@@ -251,9 +254,12 @@ class AddVersionedFileHook(hook.Hook):
     def __call__(self):
         CheckVersionedFileOp(self._cw, entity=self.entity)
 
+### Other hooks
+###############################################################################
 
 class SetRepoCacheBeforeAddHook(hook.Hook):
     """clone just after repo creation
+
     mostly helps the tests
     """
     __regid__ = 'clone_repo_after_add'
@@ -269,7 +275,12 @@ class SetRepoCacheBeforeAddHook(hook.Hook):
 
 
 class UpdateRepositoryHook(hook.Hook):
-    """add repository eid to vcs bridge cache"""
+    """add repository eid to vcs bridge cache
+
+    - Check that the type attribute is immutable
+    - refresh the cache on url changes
+
+    XXX stuff claiming to be cache but actually necessary are EVIL"""
     __regid__ = 'vcsfile.update_repository_hook'
     __select__ = hook.Hook.__select__ & is_instance('Repository')
     events = ('before_update_entity', )
@@ -297,10 +308,15 @@ class DeleteDirsOp(hook.DataOperationMixIn, hook.Operation):
     def postcommit_event(self):
         for cachedir in self.get_data():
             try:
-                shutil.rmtree(cachedir)
-                self.info('deleted repository cache at %s', cachedir)
+                try:
+                    shutil.rmtree(cachedir)
+                    self.info('deleted repository cache at %s', cachedir)
+                except OSError, exc:
+                    if (exc.errno != errno.ENOENT
+                        or getattr(exc, 'filename', None) != cachedir):
+                        raise
             except Exception:
-                self.exception('cant delete repository cache at %s', cachedir)
+                self.exception('cannot delete repository cache at %s', cachedir)
 
 class DeleteRepositoryHook(hook.Hook):
     __regid__ = 'vcsfile.add_update_repository_hook'
