@@ -10,13 +10,21 @@ from __future__ import with_statement
 __docformat__ = "restructuredtext en"
 
 import urllib2
-from os import umask, makedirs
+from os import umask, makedirs, environ
 from os.path import split, exists, dirname
 from datetime import datetime
 
+# mercurial returns strings transcoded to the local encoding, but we want
+# predictable output regardless of the current locale
+orig_encoding = environ.get('HGENCODING')
+environ['HGENCODING'] = 'utf-8'
 from mercurial import (hg, ui, context, util, encoding,
                        commands as hgcmd, phases, obsolete)
 from mercurial.node import nullid, short as short_hex
+if orig_encoding is not None:
+    environ['HGENCODING'] = orig_encoding
+else:
+    del environ['HGENCODING']
 
 from logilab.common import tempattr
 
@@ -66,6 +74,35 @@ def iter_direct_known_precursors(ctx):
                 candidates.add(mark[0])
                 seen.add(mark[0])
 
+# mercurial 2.4 at least does not contain any code to get
+# the precursors ...
+def iter_direct_known_successors(ctx):
+    obsstore = getattr(ctx._repo, 'obsstore', None)
+    if obsstore is None:
+        return
+    nodemap = ctx._repo.changelog.nodemap
+    markers = obsstore.successors.get(ctx.node(), ())
+    candidates = set()
+    for mark in markers:
+        candidates.update(set(mark[1]))
+    seen = set(candidates)
+    # we traverse chains of markers which may refer to
+    # nodes not known from the repo (because they were
+    # not pushed/pulled)
+    while candidates:
+        current = candidates.pop()
+        crev = nodemap.get(current)
+        # is the marked revision known from the repo ?
+        if crev is not None:
+            yield ctx._repo[crev]
+            continue
+        # if not, let's continue until we reach a known precursor
+        for mark in obsstore.precursors.get(current, ()):
+            for succ in mark[1]:
+                if succ not in seen:
+                    candidates.add(succ)
+                    seen.add(succ)
+
 class vcsfile_ui(ui.ui):
     """ redirect output to cubicweb log """
     def __init__(self, loggable):
@@ -264,8 +301,31 @@ class HGRepository(repo.VCSRepository):
                                 (setto, ','.join(str(revnum) for revnum in revs)),
                                 {'hg': repoentity.eid})
 
+        # very partial handling of obsolescence relation added after a revision
+        # issue #2731056
+        # this tries to find explanation for changeset that becomes hidden
+        # - does not work for changesets already hidden
+        # - does not work for public changesets
+        for new_hide in hide:
+            ctx = repo[new_hide]
+            RQL = '''SET S obsoletes P
+                     WHERE R eid %(r)s,
+                           P from_repository R,
+                           P changeset %(p)s,
+                           S from_repository R,
+                           S changeset %(s)s,
+                           NOT S obsoletes P
+            '''
+            # unknown successors will create the relation at insertion time
+            data = {'r': repoentity.eid,
+                    'p': str(ctx)}
+            for succ in iter_direct_known_successors(ctx):
+                data['s'] = str(succ)
+                session.execute(RQL, data)
+
+
     def import_revision(self, repoentity, repo, i):
-        self.info('importing revision %s', i)
+        self.info('importing revision %s from %s', i, repoentity.dc_title())
         session = repoentity._cw
         execute = session.execute
         node = repo.changelog.node(i)
@@ -279,8 +339,8 @@ class HGRepository(repo.VCSRepository):
         date = datetime.fromtimestamp(ctx.date()[0])
         #taglist = ctx.tags() #repo.nodetags(node)
         revdata = {'date': date, 'revision': i,
-                   'author': unicode(ctx.user(), self.encoding, 'replace'),
-                   'description': unicode(ctx.description(), self.encoding, 'replace'),
+                   'author': unicode(ctx.user(), 'utf-8', 'replace'),
+                   'description': unicode(ctx.description(), 'utf-8', 'replace'),
                    'changeset': changeset,
                    'phase': unicode(ctx.phasestr()),
                    'branch': unicode(ctx.branch()),
