@@ -69,3 +69,10 @@ should be commited (default to 1000).',
           }
          ),
         )
+
+from cubicweb.mttransforms import ENGINE
+from cubes.vcsfile.docparser import Diff2HTMLTransform
+
+COMPONENT_CONTEXT = 'navcontentbottom'
+
+ENGINE.add_transform(Diff2HTMLTransform())
